@@ -1,4 +1,29 @@
+"""
+## AWS AutoScaling Common Library
+
+<!--BEGIN STABILITY BANNER-->---
+
+
+![Stability: Experimental](https://img.shields.io/badge/stability-Experimental-important.svg?style=for-the-badge)
+
+> **This is a *developer preview* (public beta) module. Releases might lack important features and might have
+> future breaking changes.**
+>
+> This API is still under active development and subject to non-backward
+> compatible changes or removal in any future version. Use of the API is not recommended in production
+> environments. Experimental APIs are not subject to the Semantic Versioning model.
+
+---
+<!--END STABILITY BANNER-->
+
+This is a sister package to `@aws-cdk/aws-autoscaling` and
+`@aws-cdk/aws-applicationautoscaling`. It contains shared implementation
+details between them.
+
+It does not need to be used directly.
+"""
 import abc
+import builtins
 import datetime
 import enum
 import typing
@@ -7,11 +32,12 @@ import jsii
 import jsii.compat
 import publication
 
-from jsii.python import classproperty
-
 import aws_cdk.aws_iam
 import aws_cdk.core
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-autoscaling-common", "1.6.1", __name__, "aws-autoscaling-common@1.6.1.jsii.tgz")
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-autoscaling-common", "1.25.0", __name__, "aws-autoscaling-common@1.25.0.jsii.tgz")
+
+
 @jsii.data_type(jsii_type="@aws-cdk/aws-autoscaling-common.Alarms", jsii_struct_bases=[], name_mapping={'lower_alarm_interval_index': 'lowerAlarmIntervalIndex', 'upper_alarm_interval_index': 'upperAlarmIntervalIndex'})
 class Alarms():
     def __init__(self, *, lower_alarm_interval_index: typing.Optional[jsii.Number]=None, upper_alarm_interval_index: typing.Optional[jsii.Number]=None):
@@ -27,7 +53,7 @@ class Alarms():
         if lower_alarm_interval_index is not None: self._values["lower_alarm_interval_index"] = lower_alarm_interval_index
         if upper_alarm_interval_index is not None: self._values["upper_alarm_interval_index"] = upper_alarm_interval_index
 
-    @property
+    @builtins.property
     def lower_alarm_interval_index(self) -> typing.Optional[jsii.Number]:
         """
         stability
@@ -35,7 +61,7 @@ class Alarms():
         """
         return self._values.get('lower_alarm_interval_index')
 
-    @property
+    @builtins.property
     def upper_alarm_interval_index(self) -> typing.Optional[jsii.Number]:
         """
         stability
@@ -68,7 +94,7 @@ class ArbitraryIntervals():
             'intervals': intervals,
         }
 
-    @property
+    @builtins.property
     def absolute(self) -> bool:
         """
         stability
@@ -76,7 +102,7 @@ class ArbitraryIntervals():
         """
         return self._values.get('absolute')
 
-    @property
+    @builtins.property
     def intervals(self) -> typing.List["ScalingInterval"]:
         """
         stability
@@ -111,7 +137,7 @@ class CompleteScalingInterval():
         }
         if change is not None: self._values["change"] = change
 
-    @property
+    @builtins.property
     def lower(self) -> jsii.Number:
         """
         stability
@@ -119,7 +145,7 @@ class CompleteScalingInterval():
         """
         return self._values.get('lower')
 
-    @property
+    @builtins.property
     def upper(self) -> jsii.Number:
         """
         stability
@@ -127,7 +153,7 @@ class CompleteScalingInterval():
         """
         return self._values.get('upper')
 
-    @property
+    @builtins.property
     def change(self) -> typing.Optional[jsii.Number]:
         """
         stability
@@ -151,7 +177,7 @@ class IRandomGenerator(jsii.compat.Protocol):
     stability
     :stability: experimental
     """
-    @staticmethod
+    @builtins.staticmethod
     def __jsii_proxy_class__():
         return _IRandomGeneratorProxy
 
@@ -219,7 +245,7 @@ class ScalingInterval():
         if lower is not None: self._values["lower"] = lower
         if upper is not None: self._values["upper"] = upper
 
-    @property
+    @builtins.property
     def change(self) -> jsii.Number:
         """The capacity adjustment to apply in this interval.
 
@@ -237,7 +263,7 @@ class ScalingInterval():
         """
         return self._values.get('change')
 
-    @property
+    @builtins.property
     def lower(self) -> typing.Optional[jsii.Number]:
         """The lower bound of the interval.
 
@@ -251,7 +277,7 @@ class ScalingInterval():
         """
         return self._values.get('lower')
 
-    @property
+    @builtins.property
     def upper(self) -> typing.Optional[jsii.Number]:
         """The upper bound of the interval.
 
